@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 21 Mar 2012                                              }
+{ last modified: 25 Mar 2012                                              }
 {*************************************************************************/
 
 #include "mainwindow.h"
@@ -311,7 +311,7 @@ void MainWindow::reposition(const QSize& sz)
         btnStop->move(x, y); y = y + CONTROLBUTTON_SIZE + CONTROLBUTTON_PUSHOFFSET+ CONTROLBUTTON_PADDING;
         btnPlay->move(x, y); y = y + CONTROLBUTTON_SIZE + CONTROLBUTTON_PUSHOFFSET+ CONTROLBUTTON_PADDING;
         btnNext->move(x, y);
-        y = h - (CONTROLBUTTON_SIZE + CONTROLBUTTON_PUSHOFFSET);
+        y = h - (CONTROLBUTTON_SIZE + CONTROLBUTTON_PUSHOFFSET*3);
         btnParent->move(x,y);
     }
     KineticListItem* item;
@@ -735,28 +735,8 @@ void MainWindow::onMenuCurrentClick()
     if(!cd(FSMan::getParentDir(filename)))
         return;
 
-    int a = 0;
-    int n = itemsContainer->children().size();
-    while(a<n)
-    {
-        if(itemsContainer->children().at(a) == currentFileItem)
-            break;
-        a++;
-    }
-
-    int y = -a*ITEM_HEIGHT+itemsContainer->height()/2;
-    if(y > 0)
-    {
-        y = 0;
-    }
-    else
-    {
-        int minY = itemsContainer->getMinY();
-        if(y < minY)
-            y = minY;
-    }
-
-    itemsContainer->setY(y);
+    if(currentFileItem)
+        itemsContainer->centerWidgetV(currentFileItem);
 }
 
 void MainWindow::onMenuTypesClick()
@@ -774,6 +754,7 @@ void MainWindow::onMenuOptionsClick()
         onMenuClearClick();
     }
     updateScreenOrientation();
+    cd(fs->getCurrentDirectory());
 }
 
 void MainWindow::onMenuEqualizerClick()
@@ -875,7 +856,6 @@ void MainWindow::onHeadsetStatusChange(bool isConnected)
 
 void MainWindow::onCallStart()
 {
-    qDebug() << "CALL START";
     if(player->getState() != pp_state_Playing)
         return;
     switch(OPTIONS.incomingCallAction)
@@ -897,7 +877,6 @@ void MainWindow::onCallStart()
 
 void MainWindow::onCallEnd()
 {
-    qDebug() << "CALL END";
     if(!checkResumeOnHangup)
         return;
     checkResumeOnHangup = false;
